@@ -319,21 +319,23 @@ def create_description(name, roadName, startMarker, endMarker, typeOfWork, start
 
 
 def get_improved_geometry(coordinates, event_status, id):
-    if event_status != "active":
+    if event_status == "completed":
         return coordinates
 
-    startPoint = coordinates[0]
-    endPoint = coordinates[-1]
+    startPoint = [coordinates[0][-1], coordinates[0][0]]
+    endPoint = [coordinates[-1][-1], coordinates[-1][0]]
 
-    startRouteParams = cdot_geospatial_api.get_route_and_measure(startPoint)
-    endRouteParams = cdot_geospatial_api.get_route_and_measure(endPoint)
+    startRouteParams = cdot_geospatial_api.get_route_and_measure(
+        startPoint)
+    endRouteParams = cdot_geospatial_api.get_route_and_measure(
+        endPoint)
 
     if not startRouteParams or not endRouteParams:
-        logging.info(
+        print(
             f"1 or more routes not found, not generating improved geometry: {id}")
         return coordinates
     if startRouteParams['Route'] != endRouteParams['Route']:
-        logging.info(
+        print(
             f"Routes did not match, not generating improved geometry: {id}")
         return coordinates
 
@@ -343,6 +345,7 @@ def get_improved_geometry(coordinates, event_status, id):
         startRouteParams['Route'],
         startRouteParams['Measure'],
         endRouteParams['Measure'])
+
     finalDirection = polygon_tools.get_road_direction_from_coordinates(
         newCoordinates)
 
